==> libxcb-1.1.91-i586-P1.tgz: install/doinst.sh <==
( cd usr/X11R7/lib ; rm -rf libxcb-xfixes.so )
( cd usr/X11R7/lib ; ln -sf libxcb-xfixes.so.0.0.0 libxcb-xfixes.so )
( cd usr/X11R7/lib ; rm -rf libxcb-shm.so )
( cd usr/X11R7/lib ; ln -sf libxcb-shm.so.0.0.0 libxcb-shm.so )
( cd usr/X11R7/lib ; rm -rf libxcb-xvmc.so )
( cd usr/X11R7/lib ; ln -sf libxcb-xvmc.so.0.0.0 libxcb-xvmc.so )
( cd usr/X11R7/lib ; rm -rf libxcb-xprint.so )
( cd usr/X11R7/lib ; ln -sf libxcb-xprint.so.0.0.0 libxcb-xprint.so )
( cd usr/X11R7/lib ; rm -rf libxcb-glx.so )
( cd usr/X11R7/lib ; ln -sf libxcb-glx.so.0.0.0 libxcb-glx.so )
( cd usr/X11R7/lib ; rm -rf libxcb-shape.so )
( cd usr/X11R7/lib ; ln -sf libxcb-shape.so.0.0.0 libxcb-shape.so )
( cd usr/X11R7/lib ; rm -rf libxcb-shm.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-shm.so.0.0.0 libxcb-shm.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-res.so )
( cd usr/X11R7/lib ; ln -sf libxcb-res.so.0.0.0 libxcb-res.so )
( cd usr/X11R7/lib ; rm -rf libxcb-xlib.so )
( cd usr/X11R7/lib ; ln -sf libxcb-xlib.so.0.0.0 libxcb-xlib.so )
( cd usr/X11R7/lib ; rm -rf libxcb.so )
( cd usr/X11R7/lib ; ln -sf libxcb.so.1.0.0 libxcb.so )
( cd usr/X11R7/lib ; rm -rf libxcb-xvmc.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-xvmc.so.0.0.0 libxcb-xvmc.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-xv.so )
( cd usr/X11R7/lib ; ln -sf libxcb-xv.so.0.0.0 libxcb-xv.so )
( cd usr/X11R7/lib ; rm -rf libxcb-xtest.so )
( cd usr/X11R7/lib ; ln -sf libxcb-xtest.so.0.0.0 libxcb-xtest.so )
( cd usr/X11R7/lib ; rm -rf libxcb-dpms.so )
( cd usr/X11R7/lib ; ln -sf libxcb-dpms.so.0.0.0 libxcb-dpms.so )
( cd usr/X11R7/lib ; rm -rf libxcb-res.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-res.so.0.0.0 libxcb-res.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-xf86dri.so )
( cd usr/X11R7/lib ; ln -sf libxcb-xf86dri.so.0.0.0 libxcb-xf86dri.so )
( cd usr/X11R7/lib ; rm -rf libxcb-glx.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-glx.so.0.0.0 libxcb-glx.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-shape.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-shape.so.0.0.0 libxcb-shape.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-xinerama.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-xinerama.so.0.0.0 libxcb-xinerama.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-xtest.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-xtest.so.0.0.0 libxcb-xtest.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-screensaver.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-screensaver.so.0.0.0 libxcb-screensaver.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-render.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-render.so.0.0.0 libxcb-render.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-sync.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-sync.so.0.0.0 libxcb-sync.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-record.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-record.so.0.0.0 libxcb-record.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-xv.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-xv.so.0.0.0 libxcb-xv.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-xprint.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-xprint.so.0.0.0 libxcb-xprint.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-damage.so )
( cd usr/X11R7/lib ; ln -sf libxcb-damage.so.0.0.0 libxcb-damage.so )
( cd usr/X11R7/lib ; rm -rf libxcb-xinerama.so )
( cd usr/X11R7/lib ; ln -sf libxcb-xinerama.so.0.0.0 libxcb-xinerama.so )
( cd usr/X11R7/lib ; rm -rf libxcb-sync.so )
( cd usr/X11R7/lib ; ln -sf libxcb-sync.so.0.0.0 libxcb-sync.so )
( cd usr/X11R7/lib ; rm -rf libxcb-damage.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-damage.so.0.0.0 libxcb-damage.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-xevie.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-xevie.so.0.0.0 libxcb-xevie.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-composite.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-composite.so.0.0.0 libxcb-composite.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb.so.1 )
( cd usr/X11R7/lib ; ln -sf libxcb.so.1.0.0 libxcb.so.1 )
( cd usr/X11R7/lib ; rm -rf libxcb-xfixes.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-xfixes.so.0.0.0 libxcb-xfixes.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-composite.so )
( cd usr/X11R7/lib ; ln -sf libxcb-composite.so.0.0.0 libxcb-composite.so )
( cd usr/X11R7/lib ; rm -rf libxcb-xf86dri.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-xf86dri.so.0.0.0 libxcb-xf86dri.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-xevie.so )
( cd usr/X11R7/lib ; ln -sf libxcb-xevie.so.0.0.0 libxcb-xevie.so )
( cd usr/X11R7/lib ; rm -rf libxcb-record.so )
( cd usr/X11R7/lib ; ln -sf libxcb-record.so.0.0.0 libxcb-record.so )
( cd usr/X11R7/lib ; rm -rf libxcb-dpms.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-dpms.so.0.0.0 libxcb-dpms.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-screensaver.so )
( cd usr/X11R7/lib ; ln -sf libxcb-screensaver.so.0.0.0 libxcb-screensaver.so )
( cd usr/X11R7/lib ; rm -rf libxcb-xlib.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-xlib.so.0.0.0 libxcb-xlib.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-render.so )
( cd usr/X11R7/lib ; ln -sf libxcb-render.so.0.0.0 libxcb-render.so )
( cd usr/X11R7/lib ; rm -rf libxcb-randr.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-randr.so.0.0.0 libxcb-randr.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-randr.so )
( cd usr/X11R7/lib ; ln -sf libxcb-randr.so.0.0.0 libxcb-randr.so )

==> libxcb-1.7-i586-P1.tgz: install/doinst.sh <==
( cd usr/X11R7/lib ; rm -rf libxcb.so.1 )
( cd usr/X11R7/lib ; ln -sf libxcb.so.1.1.0 libxcb.so.1 )
( cd usr/X11R7/lib ; rm -rf libxcb.so )
( cd usr/X11R7/lib ; ln -sf libxcb.so.1.1.0 libxcb.so )
( cd usr/X11R7/lib ; rm -rf libxcb-composite.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-composite.so.0.0.0 libxcb-composite.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-composite.so )
( cd usr/X11R7/lib ; ln -sf libxcb-composite.so.0.0.0 libxcb-composite.so )
( cd usr/X11R7/lib ; rm -rf libxcb-damage.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-damage.so.0.0.0 libxcb-damage.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-damage.so )
( cd usr/X11R7/lib ; ln -sf libxcb-damage.so.0.0.0 libxcb-damage.so )
( cd usr/X11R7/lib ; rm -rf libxcb-dpms.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-dpms.so.0.0.0 libxcb-dpms.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-dpms.so )
( cd usr/X11R7/lib ; ln -sf libxcb-dpms.so.0.0.0 libxcb-dpms.so )
( cd usr/X11R7/lib ; rm -rf libxcb-dri2.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-dri2.so.0.0.0 libxcb-dri2.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-dri2.so )
( cd usr/X11R7/lib ; ln -sf libxcb-dri2.so.0.0.0 libxcb-dri2.so )
( cd usr/X11R7/lib ; rm -rf libxcb-glx.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-glx.so.0.0.0 libxcb-glx.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-glx.so )
( cd usr/X11R7/lib ; ln -sf libxcb-glx.so.0.0.0 libxcb-glx.so )
( cd usr/X11R7/lib ; rm -rf libxcb-randr.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-randr.so.0.1.0 libxcb-randr.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-randr.so )
( cd usr/X11R7/lib ; ln -sf libxcb-randr.so.0.1.0 libxcb-randr.so )
( cd usr/X11R7/lib ; rm -rf libxcb-record.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-record.so.0.0.0 libxcb-record.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-record.so )
( cd usr/X11R7/lib ; ln -sf libxcb-record.so.0.0.0 libxcb-record.so )
( cd usr/X11R7/lib ; rm -rf libxcb-render.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-render.so.0.0.0 libxcb-render.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-render.so )
( cd usr/X11R7/lib ; ln -sf libxcb-render.so.0.0.0 libxcb-render.so )
( cd usr/X11R7/lib ; rm -rf libxcb-res.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-res.so.0.0.0 libxcb-res.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-res.so )
( cd usr/X11R7/lib ; ln -sf libxcb-res.so.0.0.0 libxcb-res.so )
( cd usr/X11R7/lib ; rm -rf libxcb-screensaver.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-screensaver.so.0.0.0 libxcb-screensaver.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-screensaver.so )
( cd usr/X11R7/lib ; ln -sf libxcb-screensaver.so.0.0.0 libxcb-screensaver.so )
( cd usr/X11R7/lib ; rm -rf libxcb-shape.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-shape.so.0.0.0 libxcb-shape.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-shape.so )
( cd usr/X11R7/lib ; ln -sf libxcb-shape.so.0.0.0 libxcb-shape.so )
( cd usr/X11R7/lib ; rm -rf libxcb-shm.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-shm.so.0.0.0 libxcb-shm.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-shm.so )
( cd usr/X11R7/lib ; ln -sf libxcb-shm.so.0.0.0 libxcb-shm.so )
( cd usr/X11R7/lib ; rm -rf libxcb-sync.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-sync.so.0.0.0 libxcb-sync.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-sync.so )
( cd usr/X11R7/lib ; ln -sf libxcb-sync.so.0.0.0 libxcb-sync.so )
( cd usr/X11R7/lib ; rm -rf libxcb-xevie.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-xevie.so.0.0.0 libxcb-xevie.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-xevie.so )
( cd usr/X11R7/lib ; ln -sf libxcb-xevie.so.0.0.0 libxcb-xevie.so )
( cd usr/X11R7/lib ; rm -rf libxcb-xf86dri.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-xf86dri.so.0.0.0 libxcb-xf86dri.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-xf86dri.so )
( cd usr/X11R7/lib ; ln -sf libxcb-xf86dri.so.0.0.0 libxcb-xf86dri.so )
( cd usr/X11R7/lib ; rm -rf libxcb-xfixes.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-xfixes.so.0.0.0 libxcb-xfixes.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-xfixes.so )
( cd usr/X11R7/lib ; ln -sf libxcb-xfixes.so.0.0.0 libxcb-xfixes.so )
( cd usr/X11R7/lib ; rm -rf libxcb-xinerama.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-xinerama.so.0.0.0 libxcb-xinerama.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-xinerama.so )
( cd usr/X11R7/lib ; ln -sf libxcb-xinerama.so.0.0.0 libxcb-xinerama.so )
( cd usr/X11R7/lib ; rm -rf libxcb-xprint.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-xprint.so.0.0.0 libxcb-xprint.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-xprint.so )
( cd usr/X11R7/lib ; ln -sf libxcb-xprint.so.0.0.0 libxcb-xprint.so )
( cd usr/X11R7/lib ; rm -rf libxcb-xtest.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-xtest.so.0.0.0 libxcb-xtest.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-xtest.so )
( cd usr/X11R7/lib ; ln -sf libxcb-xtest.so.0.0.0 libxcb-xtest.so )
( cd usr/X11R7/lib ; rm -rf libxcb-xv.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-xv.so.0.0.0 libxcb-xv.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-xv.so )
( cd usr/X11R7/lib ; ln -sf libxcb-xv.so.0.0.0 libxcb-xv.so )
( cd usr/X11R7/lib ; rm -rf libxcb-xvmc.so.0 )
( cd usr/X11R7/lib ; ln -sf libxcb-xvmc.so.0.0.0 libxcb-xvmc.so.0 )
( cd usr/X11R7/lib ; rm -rf libxcb-xvmc.so )
( cd usr/X11R7/lib ; ln -sf libxcb-xvmc.so.0.0.0 libxcb-xvmc.so )
